@@ -1,8 +1,8 @@
-import json
-import re
 from enum import Enum, auto
 from itertools import takewhile
 from typing import Union
+import json
+import re
 
 __all__ = ["DmiParser"]
 
@@ -26,6 +26,9 @@ class DmiParserSectionHandle(object):
         self.bytes = 0
 
     def __str__(self) -> str:
+        """
+        @return: JSON dump string
+        """
         return json.dumps(self.__dict__)
 
 
@@ -39,15 +42,24 @@ class DmiParserSectionProp(object):
     """
 
     def __init__(self, value: str) -> None:
+        """
+        @param value: property text
+        """
         self.values = []
 
         if value:
             self.append(value)
 
     def __str__(self) -> str:
+        """
+        @return: JSON dump string
+        """
         return json.dumps(self.__dict__)
 
     def append(self, item: str) -> None:
+        """
+        @param item: item value
+        """
         self.values.append(item)
 
 
@@ -66,9 +78,16 @@ class DmiParserSection(object):
         self.props = {}
 
     def __str__(self) -> str:
+        """
+        @return: JSON dump string
+        """
         return json.dumps(self.__dict__)
 
     def append(self, key: str, prop: str) -> None:
+        """
+        @param key: property name
+        @param prop: property
+        """
         self.props[key] = prop
 
 
@@ -131,10 +150,14 @@ class DmiParser(object):
                 state = DmiParserState.GET_PROP
                 continue
 
+            lv = self._indentLv(line)
+
+            if i < len(lines) - 1:
+                lv -= self._indentLv(lines[i + 1])
+
             if DmiParserState.GET_PROP == state:
                 k, v = [x.strip() for x in line.split(":", 1)]
                 prop = DmiParserSectionProp(v)
-                lv = self._indentLv(line) - self._indentLv(lines[i + 1])
 
                 if v:
                     if -1 == lv:
@@ -150,14 +173,13 @@ class DmiParser(object):
                         continue
 
                 # Next section for this handle
-                if 0 == self._indentLv(lines[i + 1]):
-                    state = DmiParserState.GET_SECT
+                if i < len(lines) - 1:
+                    if 0 == self._indentLv(lines[i + 1]):
+                        state = DmiParserState.GET_SECT
 
             if DmiParserState.GET_PROP_ITEM == state:
                 prop.append(line.strip())
 
-                lv = self._indentLv(line) - self._indentLv(lines[i + 1])
-
                 if 0 != lv:
                     section.append(k, json.loads(str(prop)))
                     prop = None
@@ -165,32 +187,50 @@ class DmiParser(object):
 
 
 if "__main__" == __name__:
-    text = """# dmidecode 3.0
-Getting SMBIOS data from sysfs.
-SMBIOS 2.7 present.
+    from functools import partial
+    from typing import Callable, Any
 
-Handle 0x0003, DMI type 2, 17 bytes
-Base Board Information
-	Manufacturer: Intel Corporation
-	Product Name: S2600WT2R
-	Version: H21573-372
-	Serial Number: BQWL81150522
-	Asset Tag: Base Board Asset Tag
-	Features:
-		Board is a hosting board
-		Board is replaceable
-	Location In Chassis: Part Component
-	Chassis Handle: 0x0000
-	Type: Motherboard
-	Contained Object Handles: 0
+    def reportSecs(*args: str, brWidth=80) -> None:
+        """report texts format by section
 
-"""
+        @param args: text string
+        @param brWidth: br width
+        """
+        br: Callable[[Any], None] = lambda c: print("-" * c)
+        brn = partial(br, brWidth)
 
-    parser = DmiParser(text)
-    # parser = DmiParser(text, sort_keys=True, indent=2)
+        brn()
 
-    # get string
-    print(str(parser))
+        for text in args:
+            print(text)
+            brn()
 
-    # get object
-    print(json.loads(str(parser)))
+    text = (
+        "# dmidecode 3.0\n"
+        "Getting SMBIOS data from sysfs.\n"
+        "SMBIOS 2.7 present.\n"
+        "\n"
+        "Handle 0x0003, DMI type 2, 17 bytes\n"
+        "Base Board Information\n"
+        "\tManufacturer: Intel Corporation\n"
+        "\tProduct Name: S2600WT2R\n"
+        "\tVersion: H21573-372\n"
+        "\tSerial Number: BQWL81150522\n"
+        "\tAsset Tag: Base Board Asset Tag\n"
+        "\tFeatures:\n"
+        "\t\tBoard is a hosting board\n"
+        "\t\tBoard is replaceable\n"
+        "\tLocation In Chassis: Part Component\n"
+        "\tChassis Handle: 0x0000\n"
+        "\tType: Motherboard\n"
+        "\tContained Object Handles: 0\n"
+        "\n"
+    )
+
+    # parser = DmiParser(text)
+    parser = DmiParser(text, sort_keys=True, indent=2)
+
+    parsedStr = str(parser)  # get str
+    parsedObj = json.loads(str(parser))  # get object
+
+    reportSecs(parsedStr, parsedObj)
