@@ -1,12 +1,12 @@
 import json
-from pathlib import Path
 from dmiparser import DmiParser
+from pathlib import Path
 
 RDIR = Path(Path(__file__).resolve()).parents[0]
 
 
-def test_dmidecode_148():
-    testnum = 0
+def test_dmidecode_148() -> None:
+    count = 0
 
     with open(RDIR / "dmidecode_148.txt", "rt") as f:
         text = f.read()
@@ -21,6 +21,6 @@ def test_dmidecode_148():
         """
         if "0x0066" == d["handle"]["id"] and "OEM-specific Type" == d["name"]:
             assert 35 == len(d["props"]["Strings"]["values"])
-            testnum += 1
+            count += 1
 
-    assert 1 == testnum
+    assert 1 == count
