@@ -1,12 +1,12 @@
 import json
-from pathlib import Path
 from dmiparser import DmiParser
+from pathlib import Path
 
 RDIR = Path(Path(__file__).resolve()).parents[0]
 
 
-def test_dmidecode_32():
-    testnum = 0
+def test_dmidecode_32() -> None:
+    count = 0
 
     with open(RDIR / "dmidecode_32.txt", "rt") as f:
         text = f.read()
@@ -19,6 +19,6 @@ def test_dmidecode_32():
         """
         if "0x000F" == d["handle"]["id"] and "System Boot Information" == d["name"]:
             assert "No errors detected" == d["props"]["Status"]["values"][0]
-            testnum += 1
+            count += 1
 
-    assert 1 == testnum
+    assert 1 == count
